@@ -31,13 +31,13 @@
  * events in colors depending on their type. 
  *
  *   @section AUTHORS
- * Frank Kober 2009 - 2024 <BR> 
+ * Frank Kober 2009 - 2025 <BR> 
  * Nedko Arnaudov 2011 <BR> 
  * Guido Scholz 2009 <BR> 
  * Matthias Nagorni 2003 <BR> 
  * 
  *
- *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2025 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -56,6 +56,7 @@
  *
  */
 #include <getopt.h>
+#include <unistd.h>
 #include <QApplication>
 #include <QFileInfo>
 #include <QString>
@@ -97,7 +98,7 @@ int main(int argc, char *argv[])
                 s = QString(ABOUTMSG);
                 s.replace(QString("<br/>"), QString("\n"));
                 s.replace(QString("</p>"), QString("\n"));
-                s.remove(QRegExp("<[^>]*>"));
+                s.remove(QRegularExpression("<[^>]*>"));
                 out << s;
                 out.flush();
                 exit(EXIT_SUCCESS);
@@ -146,7 +147,11 @@ int main(int argc, char *argv[])
     QTranslator qtTr;
 
     if (qtTr.load(QString("qt_") + loc.name(),
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+#else
+                QLibraryInfo::path(QLibraryInfo::TranslationsPath)))
+#endif
         app.installTranslator(&qtTr);
 
     // translator for qmidiarp messages
@@ -156,7 +161,7 @@ int main(int argc, char *argv[])
         app.installTranslator(&qmidiarpTr);
 #endif
 
-    MainWindow* qmidiarp = new MainWindow(portCount, alsamidi, argv[0]);
+    MainWindow* qmidiarp = new MainWindow(portCount, alsamidi, argv[0], app.platformName());
     if (optind < argc) {
         QFileInfo fi(argv[optind]);
         if (fi.exists())
